# GoogleSheetApp MCP Server

An MCP Server for the GoogleSheetApp API.

## 🛠️ Tool List

This is automatically generated from OpenAPI schema for the GoogleSheetApp API.


| Tool | Description |
|------|-------------|
| `create_spreadsheet` | Creates a new blank Google Spreadsheet with the specified title and returns the API response. |
| `get_spreadsheet` | Retrieves detailed information about a specific Google Spreadsheet using its ID. |
| `batch_get_values` | Retrieves multiple ranges of values from a Google Spreadsheet in a single batch request. |
| `insert_dimensions` | Inserts new rows or columns into a Google Sheet at a specific position within the sheet. |
| `append_dimensions` | Appends empty rows or columns to the end of a Google Sheet. |
| `delete_dimensions` | Deletes rows or columns from a Google Sheet. |
| `add_sheet` | Adds a new sheet to an existing Google Spreadsheet. |
| `add_column_chart` | Adds a column chart to a Google Spreadsheet. |
| `add_table` | Adds a table to a Google Spreadsheet. |
| `clear_values` | Clears all values from a specified range in a Google Spreadsheet while preserving cell formatting and other properties |
| `update_values` | Updates cell values in a specified range of a Google Spreadsheet using the Sheets API |
| `get_values` | Get Values |
| `batch_clear_values` | Batch Clear Values |
| `batch_clear_values_by_data_filter` | Batch Clear Values by Data Filter |
| `get_values_by_data_filter` | Get Values By Data Filter |
| `copy_to_sheet` | Copy To Sheet |
